Kopis768PublicKey

Struct Kopis768PublicKey 

pub struct Kopis768PublicKey(/* private fields */);
A public key for this KEM

Implementations

Source

impl Kopis768PublicKey

pub const SERIALIZED_LEN: usize = KemPublicKey<KOPIS768_L>::SERIALIZED_LEN

The length of the public key when serialized to bytes

pub fn serialize(&self, out_buf: &mut [u8; 992])

Serializes this public key into out_buf, of length Self::SERIALIZED_LEN

pub fn from_bytes(bytes: &[u8; 992]) -> Self

Deserializes a public key from bytes, of length Self::SERIALIZED_LEN

Source

impl Kopis768PublicKey

pub fn encapsulate( &self, rng: &mut impl CryptoRng, ) -> (Kopis768Ciphertext, SharedSecret)

Encapsulates a fresh shared secret

pub fn encapsulate_deterministic( &self, randomness: &[u8; 32], ) -> (Kopis768Ciphertext, SharedSecret)

Encapsulates a shared secret using the given 32-byte randomness. This is deterministic given randomness, and is primarily useful for testing and known-answer test (KAT) vectors.